# NOTE: Derived from blib/lib/RPC/XML/Server.pm.
# Changes made here will be lost when autosplit again.
# See AutoSplit.pm.
package RPC::XML::Server;

#line 1232 "blib/lib/RPC/XML/Server.pm (autosplit into blib/lib/auto/RPC/XML/Server/process_request.al)"
###############################################################################
#
#   Sub Name:       process_request
#
#   Description:    This is provided for the case when we run as a subclass
#                   of Net::Server.
#
#   Arguments:      NAME      IN/OUT  TYPE      DESCRIPTION
#                   $self     in      ref       This class object
#                   $conn     in      ref       If present, it's a connection
#                                                 object from HTTP::Daemon
#
#   Returns:        void
#
###############################################################################
sub process_request
{
    my $self = shift;
    my $conn = shift;

    my ($req, $reqxml, $resp, $respxml, $compress);

    unless ($conn and ref($conn))
    {
        $conn = $self->{server}->{client};
        bless $conn, 'HTTP::Daemon::ClientConn';
        ${*$conn}{'httpd_daemon'} = $self;
    }

    while ($req = $conn->get_request)
    {
        if ($req->method eq 'HEAD')
        {
            # The HEAD method will be answered with our return headers,
            # both as a means of self-identification and a verification
            # of live-status. All the headers were pre-set in the cached
            # HTTP::Response object. Also, we don't count this for stats.
            $conn->send_response($self->{__response});
        }
        elsif ($req->method eq 'POST')
        {
            $reqxml = $req->content;
            # Is the content compressed?
            $reqxml = Compress::Zlib::uncompress($reqxml)
                if (($compress = $self->compress) &&
                    ($req->content_encoding || '') =~ $self->compress_re);
            # Dispatch will always return a RPC::XML::response
            $resp = $self->dispatch(\$reqxml);
            $respxml = $resp->as_string;
            # Now clone the pre-fab response and add content
            $resp = $self->{__response}->clone;
            if ($compress and (length($respxml) > $self->compress_thresh) and
                ($req->header('Accept-Encoding') =~ $self->compress_re))
            {
                $respxml = Compress::Zlib::compress($respxml);
                $resp->content_encoding($compress);
            }
            $resp->content($respxml);
            $resp->content_length(bytelength($respxml));
            $conn->send_response($resp);
            undef $resp;
        }
        else
        {
            $conn->send_error(&HTTP::Status::RC_FORBIDDEN);
        }
    }

    return;
}

# end of RPC::XML::Server::process_request
1;
